use std::time::Duration;

pub struct Cookie<'a> {
    /// Storage for the cookie string. Only used if this structure was derived
    /// from a string that was subsequently parsed.
    pub(crate) cookie_string: Option<&'a str>,
    pub(crate) name: &'a str,
    pub(crate) value: &'a str,
    // expires: Option<Tm>,
    pub(crate) max_age: Option<Duration>,
    /// The cookie's domain, if any.
    pub(crate) domain: Option<&'a str>,
    /// The cookie's path domain, if any.
    pub(crate) path: Option<&'a str>,
    /// Whether this cookie was marked Secure.
    pub(crate) secure: Option<bool>,
    /// Whether this cookie was marked HttpOnly.
    pub(crate) http_only: Option<bool>,
    /// The draft `SameSite` attribute.
    pub(crate) same_site: Option<SameSite>,
    pub(crate) expires: Option<&'a str>,
}

pub enum SameSite {
    None,
    Lax,
    Strict,
}
