use std::time::Duration;

use super::{Cookie, SameSite};

pub struct CookieBuilder<'a> {
    inner: Cookie<'a>,
}

impl<'a> CookieBuilder<'a> {
    pub fn build(name: &'a str, value: &'a str) -> Self {
        CookieBuilder {
            inner: Cookie {
                cookie_string: None,
                name,
                value,
                max_age: None,
                domain: None,
                path: None,
                secure: None,
                http_only: None,
                same_site: None,
                expires: None,
            },
        }
    }
    pub fn finish(self) -> Cookie<'a> {
        self.inner
    }
    pub fn max_age(mut self, duration: Duration) -> Self {
        self.inner.max_age = Some(duration);
        self
    }
    pub fn domain(mut self, domain: &'a str) -> Self {
        self.inner.domain = Some(domain);
        self
    }
    pub fn path(mut self, path: &'a str) -> Self {
        self.inner.path = Some(path);
        self
    }
    pub fn secure(mut self, secure: bool) -> Self {
        self.inner.secure = Some(secure);
        self
    }
    pub fn http_only(mut self, http_only: bool) -> Self {
        self.inner.http_only = Some(http_only);
        self
    }
    pub fn same_site(mut self, same_site: SameSite) -> Self {
        self.inner.same_site = Some(same_site);
        self
    }
    pub fn expires(mut self, expire: &'a str) -> Self {
        self.inner.expires = Some(expire);
        self
    }
    pub fn name(mut self, name: &'a str) -> Self {
        self.inner.name = name;
        self
    }
    pub fn value(mut self, value: &'a str) -> Self {
        self.inner.value = value;
        self
    }
}
